@@ -52,13 +52,19 @@ sub new {
 	undef;
 }
 
-# Generic string form, which is currently set in inches.
+# Generic string form, which is currently set in metric.
 # Normally, given the American bias in programming, I would have done
 # this as inches. However there is a long term trend towards
 # metrification, and from a support issue it is better to be a bit more
 # aggressive and use standard units by default earlier, rather than be
 # stuck with a default string form that nobody uses in future years.
-sub as_string { shift->as_cms }
+sub as_string { shift->as_metric }
+
+# Metric is cms
+sub as_metric { shift->as_cms }
+
+# Imperial is inches
+sub as_imperial { shift->as_inches }
 
 # String form in cm
 sub as_cms { $_[0]->{value} . 'cm' }
